# frozen_string_literal: true

describe WPScan::DB::DynamicFinders::Base do
  subject(:dynamic_finders) { described_class }

  # Handled in spec/lib/db/dynamic_finders/plugin and wordpress
end
